from . import importexport

def abaqus_hexahedron_writer(data_container_array, output_path = None, file_prefix = None, feature_ids_array_path = None, hourglass_stiffness = None, job_name = None, observer = None) -> int:
  """Pythonic interface to AbaqusHexahedronWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_path (QString): Sets the "OutputPath" filter property
    file_prefix (QString): Sets the "FilePrefix" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    hourglass_stiffness (int): Sets the "HourglassStiffness" filter property
    job_name (QString): Sets the "JobName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.AbaqusHexahedronWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_path is not None:
    filter.OutputPath = output_path
  if file_prefix is not None:
    filter.FilePrefix = file_prefix
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if hourglass_stiffness is not None:
    filter.HourglassStiffness = hourglass_stiffness
  if job_name is not None:
    filter.JobName = job_name
  filter.execute()
  return filter.ErrorCode

def abaqus_surface_mesh_writer(data_container_array, output_file = None, surface_mesh_face_labels_array_path = None, observer = None) -> int:
  """Pythonic interface to AbaqusSurfaceMeshWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_file (QString): Sets the "OutputFile" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.AbaqusSurfaceMeshWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  filter.execute()
  return filter.ErrorCode

def avizo_rectilinear_coordinate_writer(data_container_array, output_file = None, write_binary_file = None, units = None, feature_ids_array_path = None, observer = None) -> int:
  """Pythonic interface to AvizoRectilinearCoordinateWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_file (QString): Sets the "OutputFile" filter property
    write_binary_file (bool): Sets the "WriteBinaryFile" filter property
    units (QString): Sets the "Units" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.AvizoRectilinearCoordinateWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if write_binary_file is not None:
    filter.WriteBinaryFile = write_binary_file
  if units is not None:
    filter.Units = units
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def avizo_uniform_coordinate_writer(data_container_array, output_file = None, write_binary_file = None, units = None, feature_ids_array_path = None, observer = None) -> int:
  """Pythonic interface to AvizoUniformCoordinateWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_file (QString): Sets the "OutputFile" filter property
    write_binary_file (bool): Sets the "WriteBinaryFile" filter property
    units (QString): Sets the "Units" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.AvizoUniformCoordinateWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if write_binary_file is not None:
    filter.WriteBinaryFile = write_binary_file
  if units is not None:
    filter.Units = units
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def dx_reader(data_container_array, volume_data_container_name = None, cell_attribute_matrix_name = None, input_file = None, origin = None, spacing = None, file_was_read = None, feature_ids_array_name = None, observer = None) -> int:
  """Pythonic interface to DxReader Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    volume_data_container_name (DataArrayPath): Sets the "VolumeDataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    input_file (QString): Sets the "InputFile" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    file_was_read (bool): Sets the "FileWasRead" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.DxReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if volume_data_container_name is not None:
    filter.VolumeDataContainerName = volume_data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if file_was_read is not None:
    filter.FileWasRead = file_was_read
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  filter.execute()
  return filter.ErrorCode

def dx_writer(data_container_array, add_surface_layer = None, feature_ids_array_path = None, observer = None) -> int:
  """Pythonic interface to DxWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    add_surface_layer (bool): Sets the "AddSurfaceLayer" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.DxWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if add_surface_layer is not None:
    filter.AddSurfaceLayer = add_surface_layer
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def feature_info_reader(data_container_array, cell_attribute_matrix_name = None, cell_feature_attribute_matrix_name = None, input_file = None, create_cell_level_arrays = None, renumber_features = None, feature_ids_array_path = None, cell_phases_array_name = None, cell_euler_angles_array_name = None, feature_phases_array_name = None, feature_euler_angles_array_name = None, observer = None) -> int:
  """Pythonic interface to FeatureInfoReader Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_attribute_matrix_name (DataArrayPath): Sets the "CellAttributeMatrixName" filter property
    cell_feature_attribute_matrix_name (QString): Sets the "CellFeatureAttributeMatrixName" filter property
    input_file (QString): Sets the "InputFile" filter property
    create_cell_level_arrays (bool): Sets the "CreateCellLevelArrays" filter property
    renumber_features (bool): Sets the "RenumberFeatures" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_name (QString): Sets the "CellPhasesArrayName" filter property
    cell_euler_angles_array_name (QString): Sets the "CellEulerAnglesArrayName" filter property
    feature_phases_array_name (QString): Sets the "FeaturePhasesArrayName" filter property
    feature_euler_angles_array_name (QString): Sets the "FeatureEulerAnglesArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.FeatureInfoReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if cell_feature_attribute_matrix_name is not None:
    filter.CellFeatureAttributeMatrixName = cell_feature_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if create_cell_level_arrays is not None:
    filter.CreateCellLevelArrays = create_cell_level_arrays
  if renumber_features is not None:
    filter.RenumberFeatures = renumber_features
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_name is not None:
    filter.CellPhasesArrayName = cell_phases_array_name
  if cell_euler_angles_array_name is not None:
    filter.CellEulerAnglesArrayName = cell_euler_angles_array_name
  if feature_phases_array_name is not None:
    filter.FeaturePhasesArrayName = feature_phases_array_name
  if feature_euler_angles_array_name is not None:
    filter.FeatureEulerAnglesArrayName = feature_euler_angles_array_name
  filter.execute()
  return filter.ErrorCode

def gbcd_triangle_dumper(data_container_array, output_file = None, surface_mesh_face_labels_array_path = None, surface_mesh_face_normals_array_path = None, surface_mesh_face_areas_array_path = None, feature_euler_angles_array_path = None, observer = None) -> int:
  """Pythonic interface to GBCDTriangleDumper Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_file (QString): Sets the "OutputFile" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    surface_mesh_face_normals_array_path (DataArrayPath): Sets the "SurfaceMeshFaceNormalsArrayPath" filter property
    surface_mesh_face_areas_array_path (DataArrayPath): Sets the "SurfaceMeshFaceAreasArrayPath" filter property
    feature_euler_angles_array_path (DataArrayPath): Sets the "FeatureEulerAnglesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.GBCDTriangleDumper()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_normals_array_path is not None:
    filter.SurfaceMeshFaceNormalsArrayPath = surface_mesh_face_normals_array_path
  if surface_mesh_face_areas_array_path is not None:
    filter.SurfaceMeshFaceAreasArrayPath = surface_mesh_face_areas_array_path
  if feature_euler_angles_array_path is not None:
    filter.FeatureEulerAnglesArrayPath = feature_euler_angles_array_path
  filter.execute()
  return filter.ErrorCode

def los_alamos_fft_writer(data_container_array, feature_ids_array_path = None, cell_phases_array_path = None, cell_euler_angles_array_path = None, observer = None) -> int:
  """Pythonic interface to LosAlamosFFTWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.LosAlamosFFTWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  filter.execute()
  return filter.ErrorCode

def ph_reader(data_container_array, volume_data_container_name = None, cell_attribute_matrix_name = None, input_file = None, origin = None, spacing = None, file_was_read = None, feature_ids_array_name = None, observer = None) -> int:
  """Pythonic interface to PhReader Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    volume_data_container_name (DataArrayPath): Sets the "VolumeDataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    input_file (QString): Sets the "InputFile" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    file_was_read (bool): Sets the "FileWasRead" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.PhReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if volume_data_container_name is not None:
    filter.VolumeDataContainerName = volume_data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if file_was_read is not None:
    filter.FileWasRead = file_was_read
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  filter.execute()
  return filter.ErrorCode

def ph_writer(data_container_array, feature_ids_array_path = None, observer = None) -> int:
  """Pythonic interface to PhWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.PhWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def read_stl_file(data_container_array, surface_mesh_data_container_name = None, face_attribute_matrix_name = None, stl_file_path = None, face_normals_array_name = None, observer = None) -> int:
  """Pythonic interface to ReadStlFile Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_mesh_data_container_name (DataArrayPath): Sets the "SurfaceMeshDataContainerName" filter property
    face_attribute_matrix_name (QString): Sets the "FaceAttributeMatrixName" filter property
    stl_file_path (QString): Sets the "StlFilePath" filter property
    face_normals_array_name (QString): Sets the "FaceNormalsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.ReadStlFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_mesh_data_container_name is not None:
    filter.SurfaceMeshDataContainerName = surface_mesh_data_container_name
  if face_attribute_matrix_name is not None:
    filter.FaceAttributeMatrixName = face_attribute_matrix_name
  if stl_file_path is not None:
    filter.StlFilePath = stl_file_path
  if face_normals_array_name is not None:
    filter.FaceNormalsArrayName = face_normals_array_name
  filter.execute()
  return filter.ErrorCode

def sp_parks_dump_reader(data_container_array, volume_data_container_name = None, cell_attribute_matrix_name = None, input_file = None, origin = None, spacing = None, one_based_arrays = None, feature_ids_array_name = None, observer = None) -> int:
  """Pythonic interface to SPParksDumpReader Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    volume_data_container_name (DataArrayPath): Sets the "VolumeDataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    input_file (QString): Sets the "InputFile" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    one_based_arrays (bool): Sets the "OneBasedArrays" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.SPParksDumpReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if volume_data_container_name is not None:
    filter.VolumeDataContainerName = volume_data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if one_based_arrays is not None:
    filter.OneBasedArrays = one_based_arrays
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  filter.execute()
  return filter.ErrorCode

def sp_parks_sites_writer(data_container_array, feature_ids_array_path = None, observer = None) -> int:
  """Pythonic interface to SPParksSitesWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.SPParksSitesWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def visualize_gbcdgmt(data_container_array, output_file = None, phase_of_interest = None, misorientation_rotation = None, gbcd_array_path = None, crystal_structures_array_path = None, observer = None) -> int:
  """Pythonic interface to VisualizeGBCDGMT Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_file (QString): Sets the "OutputFile" filter property
    phase_of_interest (int): Sets the "PhaseOfInterest" filter property
    misorientation_rotation (AxisAngleInput): Sets the "MisorientationRotation" filter property
    gbcd_array_path (DataArrayPath): Sets the "GBCDArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.VisualizeGBCDGMT()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if phase_of_interest is not None:
    filter.PhaseOfInterest = phase_of_interest
  if misorientation_rotation is not None:
    filter.MisorientationRotation = misorientation_rotation
  if gbcd_array_path is not None:
    filter.GBCDArrayPath = gbcd_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  filter.execute()
  return filter.ErrorCode

def visualize_gbcd_pole_figure(data_container_array, output_file = None, phase_of_interest = None, misorientation_rotation = None, gbcd_array_path = None, crystal_structures_array_path = None, observer = None) -> int:
  """Pythonic interface to VisualizeGBCDPoleFigure Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_file (QString): Sets the "OutputFile" filter property
    phase_of_interest (int): Sets the "PhaseOfInterest" filter property
    misorientation_rotation (AxisAngleInput): Sets the "MisorientationRotation" filter property
    gbcd_array_path (DataArrayPath): Sets the "GBCDArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.VisualizeGBCDPoleFigure()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if phase_of_interest is not None:
    filter.PhaseOfInterest = phase_of_interest
  if misorientation_rotation is not None:
    filter.MisorientationRotation = misorientation_rotation
  if gbcd_array_path is not None:
    filter.GBCDArrayPath = gbcd_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  filter.execute()
  return filter.ErrorCode

def vtk_rectilinear_grid_writer(data_container_array, output_file = None, write_binary_file = None, selected_data_array_paths = None, observer = None) -> int:
  """Pythonic interface to VtkRectilinearGridWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_file (QString): Sets the "OutputFile" filter property
    write_binary_file (bool): Sets the "WriteBinaryFile" filter property
    selected_data_array_paths (std::vector<DataArrayPath>): Sets the "SelectedDataArrayPaths" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.VtkRectilinearGridWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if write_binary_file is not None:
    filter.WriteBinaryFile = write_binary_file
  if selected_data_array_paths is not None:
    filter.SelectedDataArrayPaths = selected_data_array_paths
  filter.execute()
  return filter.ErrorCode

def vtk_structured_points_reader(data_container_array, read_cell_data = None, volume_data_container_name = None, cell_attribute_matrix_name = None, read_point_data = None, vertex_data_container_name = None, vertex_attribute_matrix_name = None, input_file = None, observer = None) -> int:
  """Pythonic interface to VtkStructuredPointsReader Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    read_cell_data (bool): Sets the "ReadCellData" filter property
    volume_data_container_name (DataArrayPath): Sets the "VolumeDataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    read_point_data (bool): Sets the "ReadPointData" filter property
    vertex_data_container_name (DataArrayPath): Sets the "VertexDataContainerName" filter property
    vertex_attribute_matrix_name (QString): Sets the "VertexAttributeMatrixName" filter property
    input_file (QString): Sets the "InputFile" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.VtkStructuredPointsReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if read_cell_data is not None:
    filter.ReadCellData = read_cell_data
  if volume_data_container_name is not None:
    filter.VolumeDataContainerName = volume_data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if read_point_data is not None:
    filter.ReadPointData = read_point_data
  if vertex_data_container_name is not None:
    filter.VertexDataContainerName = vertex_data_container_name
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  filter.execute()
  return filter.ErrorCode

def write_stl_file(data_container_array, output_stl_directory = None, output_stl_prefix = None, group_by_phase = None, surface_mesh_face_labels_array_path = None, surface_mesh_face_phases_array_path = None, observer = None) -> int:
  """Pythonic interface to WriteStlFile Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_stl_directory (QString): Sets the "OutputStlDirectory" filter property
    output_stl_prefix (QString): Sets the "OutputStlPrefix" filter property
    group_by_phase (bool): Sets the "GroupByPhase" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    surface_mesh_face_phases_array_path (DataArrayPath): Sets the "SurfaceMeshFacePhasesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = importexport.WriteStlFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_stl_directory is not None:
    filter.OutputStlDirectory = output_stl_directory
  if output_stl_prefix is not None:
    filter.OutputStlPrefix = output_stl_prefix
  if group_by_phase is not None:
    filter.GroupByPhase = group_by_phase
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_phases_array_path is not None:
    filter.SurfaceMeshFacePhasesArrayPath = surface_mesh_face_phases_array_path
  filter.execute()
  return filter.ErrorCode

